@@ -3,7 +3,7 @@
  * rewriteDefine.c
  *	  routines for defining a rewrite rule
  *
- * Portions Copyright (c) 1996-2015, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2016, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *
@@ -25,6 +25,7 @@
 #include "catalog/indexing.h"
 #include "catalog/namespace.h"
 #include "catalog/objectaccess.h"
+#include "catalog/pg_inherits_fn.h"
 #include "catalog/pg_rewrite.h"
 #include "catalog/storage.h"
 #include "commands/policy.h"
@@ -411,12 +412,12 @@ DefineQueryRewrite(char *rulename,
 		 *
 		 * If so, check that the relation is empty because the storage for the
 		 * relation is going to be deleted.  Also insist that the rel not have
-		 * any triggers, indexes, child tables, policies, or RLS enabled.
-		 * (Note: these tests are too strict, because they will reject
-		 * relations that once had such but don't anymore.  But we don't
-		 * really care, because this whole business of converting relations
-		 * to views is just a kluge to allow dump/reload of views that
-		 * participate in circular dependencies.)
+		 * any triggers, indexes, child or parent tables, RLS policies, or RLS
+		 * enabled.  (Note: some of these tests are too strict, because they
+		 * will reject relations that once had such but don't anymore.  But we
+		 * don't really care, because this whole business of converting
+		 * relations to views is just a kluge to allow dump/reload of views
+		 * that participate in circular dependencies.)
 		 */
 		if (event_relation->rd_rel->relkind != RELKIND_VIEW &&
 			event_relation->rd_rel->relkind != RELKIND_MATVIEW)
@@ -453,6 +454,12 @@ DefineQueryRewrite(char *rulename,
 						 errmsg("could not convert table \"%s\" to a view because it has child tables",
 								RelationGetRelationName(event_relation))));
 
+			if (has_superclass(RelationGetRelid(event_relation)))
+				ereport(ERROR,
+						(errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
+						 errmsg("could not convert table \"%s\" to a view because it has parent tables",
+								RelationGetRelationName(event_relation))));
+
 			if (event_relation->rd_rel->relrowsecurity)
 				ereport(ERROR,
 						(errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
